@@ -14,11 +14,11 @@ Passwd::Keyring::KDEWallet - Password storage implementation based on KDE Wallet
 
 =head1 VERSION
 
-Version 0.60
+Version 1.0000
 
 =cut
 
-our $VERSION = '0.60';
+our $VERSION = '1.0000';
 
 our $APP_NAME = "Passwd::Keyring";
 our $FOLDER_NAME = "Perl-Passwd-Keyring";
@@ -277,7 +277,7 @@ Approach inspired by L<http://www.perlmonks.org/?node_id=869620>.
 =head1 BUGS
 
 Please report any bugs or feature requests to
-issue tracker at L<https://bitbucket.org/Mekk/perl-keyring-kdewallet>.
+issue tracker at L<https://helixteamhub.cloud/mekk/projects/perl/issues>.
 
 =head1 SUPPORT
 
@@ -291,11 +291,11 @@ L<http://search.cpan.org/~mekk/Passwd-Keyring-KDEWallet/>
 
 Source code is tracked at:
 
-L<https://bitbucket.org/Mekk/perl-keyring-kdewallet>
+L<https://helixteamhub.cloud/mekk/projects/perl/repositories/keyring-kdewallet>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012 Marcin Kasperski.
+Copyright 2012-2020 Marcin Kasperski.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
